===
Tag
===

.. automodule:: orangecontrib.text.tag

.. autoclass:: orangecontrib.text.tag.POSTagger
   :members:
   :special-members: __init__

.. autoclass:: orangecontrib.text.tag.StanfordPOSTagger
   :members:
   :special-members: __init__